////////////////////////////////////////////////////////////////////////////////
//
// DgDVec3D.cpp: DgDVec3D class implementation
//
// Version 6.1 - Kevin Sahr, 5/23/13
//
////////////////////////////////////////////////////////////////////////////////

#include "DgDVec3D.h"
#include <limits>

////////////////////////////////////////////////////////////////////////////////

const DgDVec3D& DgDVec3D::undefDgDVec3D = DgDVec3D(std::numeric_limits<double>::max(), std::numeric_limits<double>::max(), std::numeric_limits<double>::max());

////////////////////////////////////////////////////////////////////////////////
